==> dde-device-formatter_1.5.4.tar.xz: BUILD/translations/dde-device-formatter_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk" version="2.1">
<context>
    <name>FinishPage</name>
    <message>
        <location filename="../view/finishpage.cpp" line="42"/>
        <source>Format successful</source>
        <translation>Успішне форматування</translation>
    </message>
</context>
<context>
    <name>FormatingPage</name>
    <message>
        <location filename="../view/formatingpage.cpp" line="47"/>
        <source>Formatting the disk, please wait...</source>
        <translation>Форматуємо диск. Будь ласка, зачекайте…</translation>
    </message>
</context>
<context>
    <name>MainPage</name>
    <message>
        <location filename="../view/mainpage.cpp" line="119"/>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <location filename="../view/mainpage.cpp" line="137"/>
        <source>Label</source>
        <translation>Мітка</translation>
    </message>
    <message>
        <location filename="../view/mainpage.cpp" line="146"/>
        <source>Quick Format</source>
        <translation>Швидке форматування</translation>
    </message>
    <message>
        <location filename="../view/mainpage.cpp" line="163"/>
        <source>Formatting will erase all data on the disk.</source>
        <translation>У результаті форматування усі дані з диска буде витерто.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../view/mainwindow.cpp" line="88"/>
        <location filename="../view/mainwindow.cpp" line="106"/>
        <source>Format</source>
        <translation>Форматування</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="162"/>
        <source>Continue</source>
        <translation>Продовжити</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="167"/>
        <source>Formatting...</source>
        <translation>Форматуємо…</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="193"/>
        <source>Done</source>
        <translation>Виконано</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="199"/>
        <source>Quit</source>
        <translation>Вийти</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="200"/>
        <source>Your disk has been removed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your disk is removed when formatting</source>
        <translation type="vanished">У процесі форматування ваш диск було вилучено</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="203"/>
        <source>Failed to format the device</source>
        <translation>Не вдалося виконати форматування пристрою</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="204"/>
        <source>Reformat</source>
        <translation>Форматувати повторно</translation>
    </message>
</context>
<context>
    <name>MessageDialog</name>
    <message>
        <location filename="../dialogs/messagedialog.cpp" line="43"/>
        <source>OK</source>
        <translation>Гаразд</translation>
    </message>
</context>
<context>
    <name>QCoreApplication</name>
    <message>
        <location filename="../utils/udisksutils.cpp" line="55"/>
        <source>System Disk</source>
        <translation>Системний диск</translation>
    </message>
    <message>
        <location filename="../utils/udisksutils.cpp" line="59"/>
        <source>%1 Encrypted</source>
        <translation>Зашифровано %1</translation>
    </message>
    <message>
        <location filename="../utils/udisksutils.cpp" line="61"/>
        <source>%1 Volume</source>
        <translation>Том %1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="90"/>
        <source>Device does not exist</source>
        <translation>Пристрою не існує</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="99"/>
        <source>The device is read-only</source>
        <translation>Пристрій призначено лише для читання</translation>
    </message>
    <message>
        <source>Cannot format local device</source>
        <translation type="vanished">Неможливо виконати форматування локального пристрою</translation>
    </message>
</context>
<context>
    <name>WarnPage</name>
    <message>
        <location filename="../view/warnpage.cpp" line="43"/>
        <source>Formatting will erase all data on this disk, are you sure you want to continue? It cannot be restored.</source>
        <translation>У результаті форматування усі дані з диска буде витерто. Ви справді цього хочете. Відновити дані буде дуже важко.</translation>
    </message>
</context>
</TS>

==> dde-device-formatter_1.5.5.tar.xz: BUILD/translations/dde-device-formatter_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>FinishPage</name>
    <message>
        <location filename="../view/finishpage.cpp" line="22"/>
        <source>Format successful</source>
        <translation>Успішне форматування</translation>
    </message>
</context>
<context>
    <name>FormatingPage</name>
    <message>
        <location filename="../view/formatingpage.cpp" line="29"/>
        <source>Formatting the disk, please wait...</source>
        <translation>Форматуємо диск. Будь ласка, зачекайте…</translation>
    </message>
</context>
<context>
    <name>MainPage</name>
    <message>
        <location filename="../view/mainpage.cpp" line="99"/>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <location filename="../view/mainpage.cpp" line="117"/>
        <source>Label</source>
        <translation>Мітка</translation>
    </message>
    <message>
        <location filename="../view/mainpage.cpp" line="127"/>
        <source>Quick Format</source>
        <translation>Швидке форматування</translation>
    </message>
    <message>
        <location filename="../view/mainpage.cpp" line="144"/>
        <source>Formatting will erase all data on the disk.</source>
        <translation>У результаті форматування усі дані з диска буде витерто.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../view/mainwindow.cpp" line="68"/>
        <location filename="../view/mainwindow.cpp" line="86"/>
        <source>Format</source>
        <translation>Форматування</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="250"/>
        <source>Continue</source>
        <translation>Продовжити</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="256"/>
        <source>Formatting...</source>
        <translation>Форматуємо…</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="290"/>
        <source>Done</source>
        <translation>Виконано</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="303"/>
        <source>Quit</source>
        <translation>Вийти</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="304"/>
        <source>Your disk has been removed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="308"/>
        <source>Failed to format the device</source>
        <translation>Не вдалося виконати форматування пристрою</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="309"/>
        <source>Reformat</source>
        <translation>Форматувати повторно</translation>
    </message>
</context>
<context>
    <name>MessageDialog</name>
    <message>
        <location filename="../dialogs/messagedialog.cpp" line="23"/>
        <source>OK</source>
        <translation>Гаразд</translation>
    </message>
</context>
<context>
    <name>QCoreApplication</name>
    <message>
        <location filename="../utils/udisksutils.cpp" line="40"/>
        <source>System Disk</source>
        <translation>Системний диск</translation>
    </message>
    <message>
        <location filename="../utils/udisksutils.cpp" line="46"/>
        <source>%1 Encrypted</source>
        <translation>Зашифровано %1</translation>
    </message>
    <message>
        <location filename="../utils/udisksutils.cpp" line="50"/>
        <source>%1 Volume</source>
        <translation>Том %1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="80"/>
        <source>dde device formatter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="97"/>
        <source>Device does not exist</source>
        <translation>Пристрою не існує</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="107"/>
        <source>The device is read-only</source>
        <translation>Пристрій призначено лише для читання</translation>
    </message>
</context>
<context>
    <name>WarnPage</name>
    <message>
        <location filename="../view/warnpage.cpp" line="23"/>
        <source>Formatting will erase all data on this disk, are you sure you want to continue? It cannot be restored.</source>
        <translation>У результаті форматування усі дані з диска буде витерто. Ви справді цього хочете. Відновити дані буде дуже важко.</translation>
    </message>
</context>
</TS>
